parade.command.task package
===========================

Submodules
----------

parade.command.task.create module
---------------------------------

.. automodule:: parade.command.task.create
    :members:
    :undoc-members:
    :show-inheritance:

parade.command.task.debug module
--------------------------------

.. automodule:: parade.command.task.debug
    :members:
    :undoc-members:
    :show-inheritance:

parade.command.task.list module
-------------------------------

.. automodule:: parade.command.task.list
    :members:
    :undoc-members:
    :show-inheritance:

parade.command.task.run module
------------------------------

.. automodule:: parade.command.task.run
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: parade.command.task
    :members:
    :undoc-members:
    :show-inheritance:
